from setuptools import setup, find_packages

setup(
    name="py-ansi3",
    version="1.2.0",
    packages=find_packages(),
    url="https://github.com/mohamedlunar/PyANSI3",
    author="MohamedLunar",
    author_email="contact.mohamedlunardev@gmail.com",
    description="pip install py-ansi3",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        # Your dependencies here
    ],
)
